Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2019-02-27 02:46:48 +0300
committerCampbell Barton <ideasman42@gmail.com>2019-02-27 03:03:16 +0300
commit3051e2f4ae8fd3e72a43dd1e5d40893d0efec500 (patch)
tree6de62ee531c71705a8d86592770d26f8ecb75d1f /source/blender/editors/animation/anim_filter.c
parentce104ca89643c4b0e6358fd22a2b056ecd603e62 (diff)
DNA: rename Lamp -> Light
- BKE_lamp -> BKE_light - Main.lamp -> light
Diffstat (limited to 'source/blender/editors/animation/anim_filter.c')
-rw-r--r--source/blender/editors/animation/anim_filter.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/source/blender/editors/animation/anim_filter.c b/source/blender/editors/animation/anim_filter.c
index 2736bf8b06f..3d8eee958a3 100644
--- a/source/blender/editors/animation/anim_filter.c
+++ b/source/blender/editors/animation/anim_filter.c
@@ -672,7 +672,7 @@ static bAnimListElem *make_new_animlistelem(void *data, short datatype, ID *owne
}
case ANIMTYPE_DSLAM:
{
- Lamp *la = (Lamp *)data;
+ Light *la = (Light *)data;
AnimData *adt = la->adt;
ale->flag = FILTER_LAM_OBJD(la);
@@ -2082,7 +2082,7 @@ static size_t animdata_filter_ds_texture(bAnimContext *ac, ListBase *anim_data,
}
/* NOTE: owner_id is the direct owner of the texture stack in question
* It used to be Material/Lamp/World before the Blender Internal removal for 2.8
*/
static size_t animdata_filter_ds_textures(bAnimContext *ac, ListBase *anim_data, bDopeSheet *ads, ID *owner_id, int filter_mode)
{
@@ -2363,9 +2363,9 @@ static size_t animdata_filter_ds_obdata(bAnimContext *ac, ListBase *anim_data, b
expanded = FILTER_CAM_OBJD(ca);
break;
}
- case OB_LAMP: /* ---------- Lamp ----------- */
+ case OB_LAMP: /* ---------- Light ----------- */
{
- Lamp *la = (Lamp *)ob->data;
+ Light *la = (Light *)ob->data;
if (ads->filterflag & ADS_FILTER_NOLAM)
return 0;
@@ -2451,7 +2451,7 @@ static size_t animdata_filter_ds_obdata(bAnimContext *ac, ListBase *anim_data, b
switch (ob->type) {
case OB_LAMP: /* lamp - textures + nodetree */
{
- Lamp *la = ob->data;
+ Light *la = ob->data;
bNodeTree *ntree = la->nodetree;
/* nodetree */
@@ -2082,7 +2082,7 @@ static size_t animdata_filter_ds_texture(bAnimContext *ac, ListBase *anim_data,
}
/* NOTE: owner_id is the direct owner of the texture stack in question
- * It used to be Material/Lamp/World before the Blender Internal removal for 2.8
+ * It used to be Material/Light/World before the Blender Internal removal for 2.8
*/
static size_t animdata_filter_ds_textures(bAnimContext *ac, ListBase *anim_data, bDopeSheet *ads, ID *owner_id, int filter_mode)